@@ -30,7 +30,7 @@ def printerr(*args):
 
 def safe_mkdir(path, mode=0o700):
     try:
-        os.mkdir(path, mode)
+        os.makedirs(path, mode)
     except OSError:
         pass
 
@@ -59,6 +59,9 @@ class KeystokClient:
             self.options['verbose'] = False
         # Ensure cache directory exists
         safe_mkdir(self.options['cache_dir'], 0o700)
+        # Create full cache path with application ID in it
+        self.cache_path = os.path.join(self.options['cache_dir'], str(self.token['id']))
+        safe_mkdir(self.cache_path, 0o700)
 
     def get_key(self, key_id):
         url = '%s/apps/%s/deploy/%s?access_token=%s' % (self.options['api_host'], self.token['id'], key_id, self.refresh_access_token(self.token))
@@ -84,7 +87,7 @@ class KeystokClient:
                 print(key['id'])
 
     def cmd_get(self, key_id):
-        return self.get_key(key_id)
+        sys.stdout.write(self.get_key(key_id))
 
     def cmd_sshautoconfig(self):
         # Autoconfigure ssh with private/public keypair from Keystok and some default options.
@@ -139,7 +142,7 @@ class KeystokClient:
 
         # Do we have an access token cached?
         try:
-            cached_token = json.load(open(os.path.join(self.options['cache_dir'], 'access_token')))
+            cached_token = json.load(open(os.path.join(self.cache_path, 'access_token')))
             if cached_token['expires_at'] > int(time.time()):
                 return cached_token['access_token']
         except IOError:
@@ -154,7 +157,7 @@ class KeystokClient:
         response = requests.post(self.options['auth_host'], data).json()
         response['expires_at'] = int(time.time()) + response['expires_in']
 
-        with open(os.path.join(self.options['cache_dir'], 'access_token'), 'w') as f:
+        with open(os.path.join(self.cache_path, 'access_token'), 'w') as f:
             json.dump(response, f)
         return response['access_token']
 
@@ -202,7 +205,14 @@ def main():
     if args.access_token:
         access_token = args.access_token
     if not access_token:
-        # See if we can get it from a config file
+        # See if we can get it from a file in the current directory
+        try:
+            access_token = open(os.path.join(os.getcwd(), '.keystok', 'access_token')).read().decode('utf-8').strip()
+        except IOError:
+            # Ignore not found
+            pass
+    if not access_token:
+        # See if we can get it from a file in the global config directory
         try:
             access_token = open(os.path.join(keystok_dir, 'access_token')).read().decode('utf-8').strip()
         except IOError:
